==> ejc-outcontract-impl-3.0.0-20220808.015611-93-sources.jar: com/ejianc/foundation/outcontractDisclosure/bean/OutcontractDisclosureEntity.java <==
package com.ejianc.foundation.outcontractDisclosure.bean;

import java.util.Date;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 供方合同交底
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outcontract_disclosure")
public class OutcontractDisclosureEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="contract_id")
    private Long contractId; // 项目id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_sign_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date contractSignDate; // 合同签订时间
    @TableField(value="confidant")
    private String confidant; // 交底人
    @TableField(value="receiver")
    private String receiver; // 被交底人
    @TableField(value="confess_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date confessDate; // 交底日期
    @TableField(value="confess_address")
    private String confessAddress; // 交底地点
    @TableField(value="contract_content")
    private String contractContent; // 分供方合同工作内容及工期要求
    @TableField(value="contract_principle")
    private String contractPrinciple; // 分供方合同计量计价原则
    @TableField(value="contract_punishment")
    private String contractPunishment; // 分供方合同违约罚则
    @TableField(value="contract_agreement")
    private String contractAgreement; // 分供方合同中关于甲供材消耗的约定
    @TableField(value="other_content")
    private String otherContent; // 其他内容
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="contract_type")
    private String contractType; // 合同类型
    
    

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Date getContractSignDate() {
        return contractSignDate;
    }

    public void setContractSignDate(Date contractSignDate) {
        this.contractSignDate = contractSignDate;
    }
    public String getConfidant() {
        return confidant;
    }

    public void setConfidant(String confidant) {
        this.confidant = confidant;
    }
    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }
    public Date getConfessDate() {
        return confessDate;
    }

    public void setConfessDate(Date confessDate) {
        this.confessDate = confessDate;
    }
    public String getConfessAddress() {
        return confessAddress;
    }

    public void setConfessAddress(String confessAddress) {
        this.confessAddress = confessAddress;
    }
    public String getContractContent() {
        return contractContent;
    }

    public void setContractContent(String contractContent) {
        this.contractContent = contractContent;
    }
    public String getContractPrinciple() {
        return contractPrinciple;
    }

    public void setContractPrinciple(String contractPrinciple) {
        this.contractPrinciple = contractPrinciple;
    }
    public String getContractPunishment() {
        return contractPunishment;
    }

    public void setContractPunishment(String contractPunishment) {
        this.contractPunishment = contractPunishment;
    }
    public String getContractAgreement() {
        return contractAgreement;
    }

    public void setContractAgreement(String contractAgreement) {
        this.contractAgreement = contractAgreement;
    }
    public String getOtherContent() {
        return otherContent;
    }

    public void setOtherContent(String otherContent) {
        this.otherContent = otherContent;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }
}

==> ejc-outcontract-impl-3.0.0-20230908.070514-191-sources.jar: com/ejianc/foundation/outcontractDisclosure/bean/OutcontractDisclosureEntity.java <==
package com.ejianc.foundation.outcontractDisclosure.bean;

import java.math.BigDecimal;
import java.util.Date;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 供方合同交底
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outcontract_disclosure")
public class OutcontractDisclosureEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="contract_id")
    private Long contractId; // 项目id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_sign_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date contractSignDate; // 合同签订时间
    @TableField(value="contract_price")
    private BigDecimal contractPrice; // 合同签订金额
    @TableField(value="confidant")
    private String confidant; // 交底人
    @TableField(value="receiver")
    private String receiver; // 被交底人
    @TableField(value="confess_date")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date confessDate; // 交底日期
    @TableField(value="confess_address")
    private String confessAddress; // 交底地点
    @TableField(value="contract_content")
    private String contractContent; // 分供方合同工作内容及工期要求
    @TableField(value="contract_principle")
    private String contractPrinciple; // 分供方合同计量计价原则
    @TableField(value="contract_punishment")
    private String contractPunishment; // 分供方合同违约罚则
    @TableField(value="contract_agreement")
    private String contractAgreement; // 分供方合同中关于甲供材消耗的约定
    @TableField(value="other_content")
    private String otherContent; // 其他内容
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="contract_type")
    private String contractType; // 合同类型
    
    

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Date getContractSignDate() {
        return contractSignDate;
    }

    public void setContractSignDate(Date contractSignDate) {
        this.contractSignDate = contractSignDate;
    }
    public String getConfidant() {
        return confidant;
    }

    public void setConfidant(String confidant) {
        this.confidant = confidant;
    }
    public String getReceiver() {
        return receiver;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }
    public Date getConfessDate() {
        return confessDate;
    }

    public void setConfessDate(Date confessDate) {
        this.confessDate = confessDate;
    }
    public String getConfessAddress() {
        return confessAddress;
    }

    public void setConfessAddress(String confessAddress) {
        this.confessAddress = confessAddress;
    }
    public String getContractContent() {
        return contractContent;
    }

    public void setContractContent(String contractContent) {
        this.contractContent = contractContent;
    }
    public String getContractPrinciple() {
        return contractPrinciple;
    }

    public void setContractPrinciple(String contractPrinciple) {
        this.contractPrinciple = contractPrinciple;
    }
    public String getContractPunishment() {
        return contractPunishment;
    }

    public void setContractPunishment(String contractPunishment) {
        this.contractPunishment = contractPunishment;
    }
    public String getContractAgreement() {
        return contractAgreement;
    }

    public void setContractAgreement(String contractAgreement) {
        this.contractAgreement = contractAgreement;
    }
    public String getOtherContent() {
        return otherContent;
    }

    public void setOtherContent(String otherContent) {
        this.otherContent = otherContent;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }

    public BigDecimal getContractPrice() {
        return contractPrice;
    }

    public void setContractPrice(BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
}
